@@ -86,6 +86,7 @@ ical_new (char *comment, char *organizer, char *summary)
 	ico->summary   = g_strdup (summary);
 	ico->class     = g_strdup ("PUBLIC");
 	ico->status    = g_strdup ("NEEDS ACTION");
+	ico->categories= NULL;
 
 	default_alarm  (ico, &ico->dalarm, organizer, ALARM_DISPLAY);
 	default_alarm  (ico, &ico->palarm, organizer, ALARM_PROGRAM);
@@ -987,7 +988,7 @@ ical_object_to_vobject (iCalObject *ical)
 
 	/* resources */
 	if (ical->resources)
-		store_list (o, VCCategoriesProp, ical->resources);
+		store_list (o, VCResourcesProp, ical->resources);
 
 	/* priority */
 	addPropValue (o, VCPriorityProp, to_str (ical->priority));
